@@ -24,7 +24,8 @@
 #endif
 
 #include <string.h>
-#include <gnome.h>
+#include <glib.h>
+#include <glib/gi18n.h>
 #include "gok-key.h"
 #include "gok-keyboard.h"
 #include "gok-mousecontrol.h"
@@ -680,7 +681,6 @@ GokKey* gok_key_new (GokKey* pKeyPrevious, GokKey* pKeyNext, GokKeyboard* pKeybo
 	pgok_key_new->BottomWin = 0;
 	pgok_key_new->LeftWin = 0;
 	pgok_key_new->RightWin = 0;
-	pgok_key_new->pMimicKey = NULL;
 	pgok_key_new->pKeyNext = pKeyNext;
 	pgok_key_new->pKeyPrevious = pKeyPrevious;
 	pgok_key_new->accessible_node = NULL;
@@ -1523,18 +1523,12 @@ gok_key_status_image (GokKey *key)
 #else
 	icon_name = "small-empty.png";
 #endif
-	file = gnome_program_locate_file (NULL, GNOME_FILE_DOMAIN_APP_DATADIR,
-					  icon_name,
-					  FALSE, NULL);
-
-	if (file) {
-		image = gtk_image_new_from_file (file);
-		g_free (file);
-	}
+	file = g_strdup_printf (DATADIR "/gok/%s", icon_name);
+	image = gtk_image_new_from_file (file);
+	g_free (file);
 
 	return image;
 }
-	
 
 /**
 * gok_key_create_image_widget
@@ -2431,9 +2425,11 @@ gok_key_get_image_filename (GokKey* pKey)
 	gchar *filename = NULL;
 	g_assert (pKey != NULL);
 
-	filename = gnome_program_locate_file (NULL, GNOME_FILE_DOMAIN_APP_DATADIR,
-					      pKey->pImage->Filename,
-					      FALSE, NULL);
+	if (pKey->pImage && pKey->pImage->Filename)
+	{
+		filename = g_strdup_printf (DATADIR "/gok/%s",
+					    pKey->pImage->Filename);
+	}
 	return filename;
 }
 
