@@ -20,7 +20,7 @@
 */
 
 #include <string.h>
-#include <libgnome/gnome-macros.h>
+
 #include "gok-log.h"
 #include "gok-sliding-window-word-complete.h"
 
@@ -32,13 +32,12 @@ static const gchar* sw_wordcomplete_get_delimiter (GokWordComplete *complete);
 
 /* 
  * This macro initializes GokUtf8WordComplete with the GType system 
- *   and defines ..._class_init and ..._instance_init functions 
+ *   and defines ..._class_init and ..._init functions and a ..._parent_class pointer.
  */
-GNOME_CLASS_BOILERPLATE (GokSWWordComplete, gok_sw_wordcomplete,
-			 GokUTF8WordComplete, GOK_TYPE_UTF8WORDCOMPLETE)
+G_DEFINE_TYPE (GokSWWordComplete, gok_sw_wordcomplete, GOK_TYPE_UTF8WORDCOMPLETE)
 
 static void
-gok_sw_wordcomplete_instance_init (GokSWWordComplete *complete)
+gok_sw_wordcomplete_init (GokSWWordComplete *complete)
 {
     g_message ("created a sliding window word completion engine.\n");
 }
@@ -46,9 +45,7 @@ gok_sw_wordcomplete_instance_init (GokSWWordComplete *complete)
 static void
 gok_sw_wordcomplete_class_init (GokSWWordCompleteClass *klass)
 {
-    GokWordCompleteClass *word_complete_class = (GokWordCompleteClass *) klass;
-   
-    parent_class = g_type_class_peek_parent (klass);
+    GokWordCompleteClass *word_complete_class = GOK_WORDCOMPLETE_CLASS (klass);
 
     word_complete_class->get_delimiter = sw_wordcomplete_get_delimiter;
     word_complete_class->predict_string = sw_wordcomplete_predict_string;
@@ -62,7 +59,7 @@ static gchar** sw_wordcomplete_predict_string (GokWordComplete *complete, const
 	cp = g_utf8_offset_to_pointer (pWord, len - 1);
     else
 	cp = pWord;
-    return GOK_WORDCOMPLETE_CLASS (parent_class)->predict_string (complete, cp, num_predictions);
+    return GOK_WORDCOMPLETE_CLASS (gok_sw_wordcomplete_parent_class)->predict_string (complete, cp, num_predictions);
 }
 
 static const gchar* sw_wordcomplete_get_delimiter (GokWordComplete *complete)
